# -*- coding: utf-8 -*-
##################################################
#
# network
# Package | Network
#
# Daniel Bakas Amuchastegui
# March 16, 2020
# 
# Copyright © Semantyk 2020. All rights reserved.
##################################################

from . import genealogical_tree
from . import network

from .genealogical_tree import *
from .network import *