# -*- coding: utf-8 -*-
##################################################
#
# article
# Module | Article
# 
# Written compositions describing the content of 
# a Resouce, through the use of Cells.
#
# Daniel Bakas Amuchastegui
# September 3, 2019
# 
# Copyright © Semantyk 2020. All rights reserved.
##################################################