# -*- coding: utf-8 -*-
##################################################
#
# semantyk 
# Package | Semantyk
#
# Author: Daniel Bakas Amuchastegui
# August 31, 2017
# 
# Copyright © Semantyk 2020. All rights reserved.
##################################################

__author__ = 'Daniel Bakas Amuchastegui'
__email__ = 'danielbakas@gmail.com'
__version__ = '0.0.0.48'

from . import archive
from . import av_reality
from . import das
from . import dots
from . import dvm
from . import games
from . import learn
from . import sam
from . import store
from . import tools
from . import uuid_generator

from .archive import *
from .av_reality import *
from .dots import *
from .dvm import *
from .games import *
from .learn import *
from .sam import *
from .store import *
from .tools import *
from .uuid_generator import *