# -*- coding: utf-8 -*-
##################################################
#
# file
# Module | File
# 
# Structured and compact formats diplaying the 
# content of a Resource, through the use of Cells.
#
# Daniel Bakas Amuchastegui
# September 3, 2019
# 
# Copyright © Semantyk 2020. All rights reserved.
##################################################