# -*- coding: utf-8 -*-
##################################################
#
# cell
# Module | Cell
# 
# Main component of a Data Visualization Model 
# like Articles or File Cards.
#
# Daniel Bakas Amuchastegui
# September 3, 2019
# 
# Copyright © Semantyk 2020. All rights reserved.
##################################################